+++
fragment = "content"
date = "2019-10-24"
weight = 100

title = "Hardware Interfaces"
+++

## Intro

This page documents what is required from hardware platform (and
specifically the software interfaces used) to integrate well into
Apertis.

For Apertis to easily be able to support a variety of hardware, it is
important that a consistent set of userspace components can be used
independant of hardware.

To best way achieve this and in line with the general [Upstream
First](https://designs.apertis.org/latest/contribution-process.html#upstream-first-policy)
strategy, Apertis relies on upstream interfaces and frameworks to access
the hardware. Interfaces that aren't supported upstream (or cannot go
upstream for whatever) require extra effort to support, test and
maintain, which means they're a very bad choice in both the short and
the long-term.

Furthermore, to enable Apertis to meaningfully debug, fix and improve
the hardware enablement if and when needed, the hardware support should
be open source. Unfortunately on most ARM platforms this is not yet
achievable, specifically and typically the EGL/GL stack for the 3D GPU
on ARM platforms is not available as open source (although this seems to
be improving). However even in that case, the components should be
freely distributable (such that apertis images can be distributed with
them) and use standard APIs.

# Hardware enablement

The following sections highlight for different type of hardware what
software interface should be provided to enable it. As the list is not
(meant to be_ exhaustive with respect to all available types of
hardware (e.g. new types of hardware not currently support by Apertis
may not be there), please ask on the Apertis developers list for
guidance if not included and when in doubt.

In general the overall guidance is simply if there are well-established
kernel interfaces for a type of device those should obviously be used
without further question and won't be included in this list (e.g.
ethernet drivers, USB stack, block drivers etc).

## bootloader

The very first bit of hardware enablement required when booting a
device, is ofcourse the bootloader. In Apertis the bootloader doesn't
only play the role of doing the basic hardware setup but is also a
fundamental part of the rollback design as it has to decide when to
rollback/boot a previous version of the system. As such Apertis
currently only supports two bootloaders:

  - u-boot: Typically used on ARM. Hardware support should be integrated
    in the upstream u-boot version \>= 2017.01 or newer. (In future
    Apertis intends to move to one u-boot source tree for all ARM
    systems).
  - gummiboot/systemd-boot: Used for Intel EFI systems. Work for
    supporting rollback with this bootloader is pending. (on the
    hardware side this mostly requires a valid EFI implementation)

## kernel

Apertis uses a Linux kernel that is as close to upstream as possible and
regularily updates its base kernel version. Therefor it's recommended
that any hardware enablement done for Apertis is also upstream, to both
minimize the delta with upstream and make it easier to update to newer
versions. At the time of this writing support at least Linux 4.9
(Long-term kernel and baseline for the next stable LTSI kernel) is
recommended.

### Specific kernel areas

#### Graphics

The graphical subsystem on modern system tends to be divided in various
specific IP blocks. Typically there is a separate display subsystem
(controller the screen, overlays etc) and at least a seperate 3D GPU.
All these blocks should be exposed via the kernel DRM and KMS interfaces
to user-space.

Furthermore for future optimizations it is recommended that the Display
subsystem support Atomic modesetting.

#### Directly attached cameras

For directly attached cameras (e.g. via a MIPI-CSI interface) should be
exposed via the standard Video for Linux 2 APIs (V4L2). To ensure
efficient sharing of the capture data with other hardware componets
(e.g. for displaying) the captured frames the driver should support
exporting the frame via dma buffers
[1](https://linuxtv.org/downloads/v4l-dvb-apis/vidioc-expbuf.html)

#### bluetooth

Apertis uses the standard linux bluetooth stack (bluez). Any bluetooth
device should support this stack.

#### Wireless lan

Apertis uses the standard linux interface for configuring wireless
devices. On the driver side that means it should use the kernels
cfg80211 framework (either directly or indirectly via mac80211 depending
on whether it's a full mac or a soft mac device).

#### Audio

Apertis uses pulseaudio on top of the standard ALSA framework. This
should be supported by audio input and output devices. As Audio routing
on a SOC is often quite complicated, it is recommended that a UCM policy
is provided if the standard pulseaudio paths aren't enough (e.g.
typically not needed for Intel HDA or very simple codecs).

#### Input device

Apertis uses the standard linux input even subsystem (evdev). For
multitouch screens protocol type B should be used (which allows
fingertracking)[2](https://www.kernel.org/doc/Documentation/input/multi-touch-protocol.txt).

#### hardware video decoding

Video decoding support in hardware exists in a few different forms, but
at the two extremes there are:

  - Fix function decoders: These device are specifically and only for
    decoding video, their input is a full or slightly pre-processed
    video frame.
  - Dynamic decoders: These device are typically part of the GPU and are
    mostly (like a GPU) programmed by userspace for the decoding. They
    may either accelerate parts of the decoding or do the full decoding.

For the former category the standard linux video for linux 2 (V4L2)
decoder interface should be exposed
[3](https://linuxtv.org/downloads/v4l-dvb-apis/codec.html) which is
directly supported by Gstreamer.

The latter category typically needs more support on the user-space side,
in which case a GStreamer plugin should be provided. E.g. Gstreamer
VAAPI as available for intel systems.

Note that it's typical these days for ARM platforms to implement the
OpenMAX specification for video playback (as used by Android). However
while there exists GStreamer plugins for using OpenMAX IL the
integration is generally poor as OpenMAX is a bad fit for GStreamer (and
needs hardware specific extensions to integrate well and generally is
more intended for application rather then media framework usage ).

#### Sensors

Generic sensors should be exposed through the Linux Industrial I/O
subsystem[4](https://www.kernel.org/doc/html/latest/driver-api/iio/index.html)

## Userspace components

### Multimedia

Apertis uses Gstreamer throughout as it's multimedia framework. As such
all platform Multimedia components (e.g. audio decoders, video capture
etc), when not using e.g. common kernel interfaces directly supported by
GStreamer this functionality should in the form of Gstreamer plugins.
These should support at least GStreamer version 1.8

### Graphics

Apart from the kernel side of graphics support there is a big hardware
specific part required to be done by user-space, specifically for the 3D
GPU in the form of an EGL/GLES2 stack. The EGL/GLES2 stack should
support the GBM platform (KHR_platform_gbm) for usage by wayland
compositors, the WL EGL platform and extensions for wayland clients.
Furthermore dmabuf importing (EXT_image_dma_buf_import) should be
supported to allow for efficient importing of output from either the
camera subsystems or the hardware video decoder.

### Voice/3G Modems

Any modem hardware should be support via ofono plugins.