+++
fragment = "content"
date = "2018-12-19"
weight = 100

title = "Template:TestCase"
+++

<noinclude>

## Usage

Use the following wiki code to include this template:

    {{ TestCase | id =
    | type = Unit | Functional | Performance | Reliability | Usability
    | priority = Low | Medium | High | Critical
    | execution_type = Manual | Automated
    | lava = N/A | Integrated | Not Integrated
    | image = Any | Development | SDK | Target
    | target = Any | VirtualBox | X86 Reference | i.MX6 Sabrelite | i.MX53 | <other specific device>
    | state = Final | Devel | <Task number> | Deprecated
    | description =
    | resources = (optional)
    | preconditions = (optional)
    | execution =
    | results =
    | postconditions = (optional)
    | notes = (optional)
    }}

Each test case contains several pieces of metadata as explained bellow:

  - **id**: Identifier of the test. Give it a meaningful name in form of
    "component-feature-subfeature" if applicable, and all lower case.
    E.g. gstreamer-video-playback.
  - **priority**: The importance and therefore frequency of testing for
    the test case.
  - **type**: The test type. (Check possible values.)
  - **execution_type**: The test category. "Manual" is for tests run by
    hand and "Automated" is for tests run in LAVA or other automated
    system.
  - **lava**: The status of LAVA integration. If not specified, the
    default value is "Not Integrated". (Check possible values)
  - **target**: The target system required to run the test. If not
    specified, the default value is "Any". (Check possible values)
  - **image**: The image required to run the test. If not specified, the
    default value is "Any". (Check possible values)
  - **state**: The state of the test case. (Check possible values)
  - **description**: A well explained description of what will be
    tested. Describes which feature is going to be tested and give some
    details about it. Ideally begin this section with a short summary
    before going into great detail. E.g. Test playback of video files on
    a window and fullscreen using GStreamer. For this the script X is
    executed first, then run Y and execute steps A-B-C which ensure
    feature Z is properly tested.

Values for the "**priority**" parameter include:

  - **Critical**: tested at least once a week, would block release if
    failing
  - **High**: tested at least once a week
  - **Medium**: tested at least once every two weeks
  - **Low**: tested as best effort

Values for the "**type**" parameter include:

  - **Unit**: Testing a unit of code
  - **Functional**: Testing a feature or function of the system
  - **Performance**: Testing speed/efficiency of the system
  - **Reliability**: Testing robustness of the system
  - **Usability**: Testing how easy it is to use the system

Values for the "**execution_type**" parameter include:

  - **Manual**: The test case has to be run by hand or initiated
    manually.
  - **Automated**: The test case is automated and can be integrated
    inside the automated system.

Values for the "**lava**" parameter include:

  - **N/A**: There is no plan to integrate that test with LAVA system.
  - **Not Integrated**: The test case is not yet automated or integrated
    to LAVA.
  - **Integrated**: The test case can be run by LAVA.

Values for the "**target**" parameter include:

  - **Any**: The test case is designed to run on any target platform
  - **VirtualBox**: The test case is designed to run within the
    VirtualBox emulator
  - **X86 Reference**: The test case is designed to run on the specified
    [Reference Hardware]( {{< ref "/reference_hardware.md" >}} )
  - **i.MX6 Sabrelite**: The test case is designed to run on a Sabrelite
    board.
  - **i.MX53**: The test case is designed to run on a i.MX53 board.
  - **<other specific device>**: The test case is designed to run on the
    specified hardware passed for this parameter.

Values for the "**image**" parameter include:

  - **Any**: The test case is designed to run on any image.
  - **Development**: The test case is designed to run on the development
    image.
  - **SDK**: The test case is designed to run on the SDK image.
  - **Target**: The test case is designed to run on target image.

Values for the "**state**" parameter include:

  - **Final**: The test case can be used for testing. For all other
    values, a message will appear at the top of the page.
  - **Devel**: The test case is still under development and should not
    be used.
  - '''
    <Task number>
    ''': Same as Devel, but there will also be a link pointing to the
    bug report tracking the test case development.
  - **Deprecated**: The test case is deprecated and should no longer be
    used.

Each test case can optionally contain the following bullet lists:

  - **resources**: A bullet list of prerequisites such as hardware,
    tools, services or resources in general needed to run the test. For
    example:

`* Intel development board model X.Y.Z`
`* Bluetooth dongle`
`* Internet connection`
`* Jabber server`

  - **notes**: A bulleted list of additional notes, references, links or
    general information about the test case.

Each test case *must* contain "**execution**" and "**results**"
parameters and may optionally contain "**preconditions**" and
"**postconditions**" parameters.

  - **preconditions**: A numbered list of steps to prepare the resources
    to execute the tests, but not really running the tests themselves.
    For example:

`# Install packages X, Y and Z.`
`#: `

    sudo apt-get install X Y Z

`# Make sure that kernel module foo is installed.`
`#: `

    sudo lsmod | grep foo

`# Etc.`

  - **execution**: A numbered list of steps to execute the tests and the
    expected output (if any) of each step. For example:

`# Check if the Bluetooth device can discover other devices as they appear and disappear.`
`#: `

    ./check-bt-disco

`# Check that other Bluetooth devices can see this one and that it properly stops emitting when disabled.`
`#: `

    ./example-command.sh

`# Verify the power consumption difference when enabled/disabled.`
` #: `

    cat /proc/foo

`# Pair the Bluetooth device with another, check if passcode prompts work properly.`
`#: `

    /usr/bin/bt-mng --foo

  - **results**: Free-form text describing the expected result of
    running the test. The result can be description of an event,
    something showing on the screen or even a text output expected from
    a command.
  - **postconditions**: A numbered list of steps to take after a test
    has been run in order to return the target to a normal state. For
    example:

`# Restore configuration variable "x" to previous value "y".`

## Template

</noinclude>  <includeonly>[Category:QA/Obsolete Test
Cases]( {{< ref "/category_qa/obsolete_test_cases.md" >}} )</includeonly>