+++
fragment = "content"
date = "2018-06-28"
weight = 100

title = "Template:TestSuite"
+++

<noinclude>

## Usage

Use the following wiki code to include this template:

    {{ TestSuite | id =
    | type = Unit | Functional | Performance | Reliability | Usability
    | priority = Low | Medium | High | Critical
    | execution_type = Manual | Automated
    | lava = N/A | Integrated | Not Integrated
    | image = Any | Development | SDK | Target
    | target = Any | VirtualBox | X86 Reference | i.MX6 Sabrelite | i.MX53 | <other specific device>
    | state = Final | Devel | <Task number> | Deprecated
    | description =
    | testcases =
    | notes = (optional)
    }}

Each test suite contains several pieces of metadata as explained bellow:

  - **id**: Identifier of the test suite. Give it a meaningful name in
    form of "component-feature" if applicable, and all lower case. E.g.
    gstreamer-video.
  - **priority**: The importance and therefore frequency of testing for
    the test cases in the suite.
  - **type**: The type of tests in the suite. (Check possible values.)
  - **execution_type**: The test category. "Manual" is for tests run by
    hand and "Automated" is for tests run in LAVA or other automated
    system.
  - **lava**: The status of LAVA integration. If not specified, the
    default value is "Not Integrated". (Check possible values)
  - **target**: The target system required to run the tests. If not
    specified, the default value is "Any". (Check possible values)
  - **image**: The image required to run the tests. If not specified,
    the default value is "Any". (Check possible values)
  - **state**: The state of the test suite. (Check possible values)
  - **description**: A well explained description of what will be
    tested. Describes which feature is going to be tested and give some
    details about it. Ideally begin this section with a short summary
    before going into great detail. E.g. Test playback of video files on
    a window and fullscreen using GStreamer. For this the script X is
    executed first, then run Y and execute steps A-B-C which ensure
    feature Z is properly tested.

Values for the "**priority**" parameter include:

  - **Critical**: tested at least once a week, would block release if
    failing
  - **High**: tested at least once a week
  - **Medium**: tested at least once every two weeks
  - **Low**: tested as best effort

Values for the "**type**" parameter include:

  - **Unit**: Testing a unit of code
  - **Functional**: Testing a feature or function of the system
  - **Performance**: Testing speed/efficiency of the system
  - **Reliability**: Testing robustness of the system
  - **Usability**: Testing how easy it is to use the system

Values for the "**execution_type**" parameter include:

  - **Manual**: The test case has to be run by hand or initiated
    manually.
  - **Automated**: The test case is automated and can be integrated
    inside the automated system.

Values for the "**lava**" parameter include:

  - **N/A**: There is no plan to integrate that test with LAVA system.
  - **Not Integrated**: The test case is not yet automated or integrated
    to LAVA.
  - **Integrated**: The test case can be run by LAVA.

Values for the "**target**" parameter include:

  - **Any**: The test case is designed to run on any target platform
  - **VirtualBox**: The test case is designed to run within the
    VirtualBox emulator
  - **X86 Reference**: The test case is designed to run on the specified
    [Reference Hardware]( {{< ref "/reference_hardware.md" >}} )
  - **i.MX6 Sabrelite**: The test case is designed to run on a Sabrelite
    board.
  - **i.MX53**: The test case is designed to run on a i.MX53 board.
  - **<other specific device>**: The test case is designed to run on the
    specified hardware passed for this parameter.

Values for the "**image**" parameter include:

  - **Any**: The test case is designed to run on any image.
  - **Development**: The test case is designed to run on the development
    image.
  - **SDK**: The test case is designed to run on the SDK image.
  - **Target**: The test case is designed to run on target image.

Values for the "**state**" parameter include:

  - **Final**: The test case can be used for testing. For all other
    values, a message will appear at the top of the page.
  - **Devel**: The test case is still under development and should not
    be used.
  - '''
    <Task number>
    ''': Same as Devel, but there will also be a link pointing to the
    bug report tracking the test case development.
  - **Deprecated**: The test case is deprecated and should no longer be
    used.

**testcases**: A bullet list of links to the test cases in the suite.
For example:

`* `[`gstreamer-video-playback`]( {{< ref "/qa/test_cases/gstreamer-video-playback.md" >}} )
`* `[`gstreamer-video-record`]( {{< ref "/qa/test_cases/gstreamer-video-record.md" >}} )

**notes**: An optional bulleted list of additional notes, references,
links or general information about the test case.

## Template

</noinclude>

<div style="display: none !important;">

{{\#vardefine: ucSTATE |  }} {{\#vardefine: ucLAVA |  }}

{{\#vardefine: warnMessage1 | This test case is still under development
and should not be executed. For more information, please contact the
page owner}} {{\#vardefine: warnMessage2 | or check ticket
\[<https://phabricator.collabora.co.uk/>{{\#var: ucSTATE}} {{\#var:
ucSTATE}}\] }} {{\#vardefine: warnMessage3 | This test case is
deprecated and should not be executed. For more information, please
contact the page owner}} {{\#vardefine: outMessage | {{\#switch:
{{\#var: ucSTATE}} |  = |  = {{\#var: warnMessage1}}. |  = {{\#var:
warnMessage3}}. | {{\#var: warnMessage1}} {{\#var: warnMessage2}}. }} }}

</div>

<span style="color:red; font-size:14pt; text-align:center;">'''{{\#var:
outMessage}}</span>

## Test Suite

  - **Id**:
  - **Type**:
  - **Priority**:
  - **Execution Type**:
  - **LAVA Integration**: {{\#if:  |  | Not Integrated}}
  - **Target**: {{\#if:  |  | Any}}
  - **Image Type**: {{\#if:  |  | Any}}

### Description

<noinclude>

GStreamer playback and record

  - Verify the video playback works
  - Verify the video recording works

</noinclude> <includeonly>{{\#if: |</includeonly>

### Test cases

<noinclude>\* </noinclude><noinclude> </noinclude><includeonly>|}}
</includeonly>

<includeonly>{{\#if: |</includeonly>

### Notes

  - Make sure that you have disconnect the ethernet connection to the
    target before you start the tethering process.

<noinclude>\* </noinclude><noinclude>

  - Example note</noinclude><includeonly>|}}

</includeonly>

{{\#switch: {{\#var: ucSTATE}} | |  = [Category:QA/Test
Suites]( {{< ref "/category_qa/test_suites.md" >}} ) |  =
[Category:QA/Deprecated Test
Suites]( {{< ref "/category_qa/deprecated_test_suites.md" >}} ) |  =
[Category:QA/Under Development Test
Suites]( {{< ref "/category_qa/under_development_test_suites.md" >}} ) |
\#default = [Category:QA/Test
Suites]( {{< ref "/category_qa/test_suites.md" >}} ) }}

{{\#ifeq: {{\#var: ucSTATE}} |  | |

` {{#ifeq: {{#var: ucLAVA}} | `` | `[`Category:QA/Integrated``
 ``Test``
 ``Suites`]( {{< ref "/category_qa/integrated_test_suites.md" >}} )` | | }}`

}} <noinclude>[Category:QA/Test
suite/Template]( {{< ref "/category_qa/test_suite/template.md" >}} )</noinclude>